@@ -1,7 +1,6 @@
 """Exposed functions."""
-from .utils.files import _get_shared_vocab as get_shared_vocab
+from .utils.files import get_shared_vocab
 from .utils.files import load_vocab
-from .utils.files import load_shared_vocab
 from .utils.files import count_lines
 from .utils.files import load_sparse
 from .utils.files import load_dense
@@ -13,7 +12,10 @@ from .utils.metrix import similarity
 from .utils.metrix import spearman
 from .utils.metrix import pearson
 from .utils.metrix import rmse
+from .utils.metrix import hmean
+from .utils.stats import steiger_test_pval
 from .core.reducer import _reduce_dense as reduce_dense
 from .core.reducer import _get_shared_vocab as get_shared_vocab
 from .core.reducer import _reduce_sparse as reduce_sparse
 from .core.converter import convert_to_txt
+from .core.evaluator import evaluate_word_similarity
