@@ -6,7 +6,7 @@ import scipy.stats as stats
 
 logger = logging.getLogger(__name__)
 
-__all__ = ('purity', 'spearman', 'similarity')
+__all__ = ('purity', 'spearman', 'similarity', 'rmse', 'pearson', 'hmean')
 
 
 # pylint: disable=C0103,W0622
@@ -37,6 +37,11 @@ def purity(y_true, y_pred):
     return 1. / len(y_true) * np.sum(np.max(M, axis=1))
 
 
+def hmean(values):
+    """Return harmonic mean of values."""
+    return stats.hmean(values)
+
+
 def rmse(x, y):
     """Return root mean squared error."""
     return np.sqrt(((x - y) ** 2).mean())
